{% if jobs %}
<table>
    <thead><tr><th>Stage</th><th>Job</th><th>Status</th></tr></thead>
    <tbody>
        {% for j in jobs %}
        <tr>
            <td>{{ j.stage }}</td>
            <td><a href="{{ j.web_url }}" target="_blank">{{ j.name }}</a></td>
            <td><span class="dot dot-{{ j.status }}"></span> {{ j.status }}</td>
        </tr>
        {% endfor %}
    </tbody>
</table>
{% else %}
<p>No jobs.</p>
{% endif %}
