<!DOCTYPE html>
<html lang="en" data-theme="auto">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>project-hub {{ hub_cwd }}{% if hub_mcp %} (mcp){% endif %}</title>
    <link rel="icon" type="image/svg+xml" href="/static/logo.svg">
    <link rel="stylesheet" href="/static/pico.min.css">
    <link rel="stylesheet" href="/static/style.css">
</head>
<body>
    <main class="container">
        <div class="loading-container">
            <h2 aria-busy="true">Waiting for first refresh...</h2>
            <p>Data is being fetched. This page will reload automatically.</p>
        </div>
    </main>
    <script src="/static/htmx.min.js"></script>
    <script>
        // Auto-reload after a few seconds to check if data is ready
        setTimeout(function() { window.location.reload(); }, 3000);
    </script>
</body>
</html>
