{% if state and state.sync_status == "in_progress" %}
<button class="outline" disabled aria-busy="true">Syncing…</button>
{% else %}
<button class="outline" hx-post="/action/sync" hx-swap="none" data-after="refresh-polls">&#x21BB; Sync</button>
{% endif %}
