{% if "vulnerabilities" in (unsupported_features or []) %}
<p class="text-center-muted">Vulnerability reporting is not supported by this provider.</p>
{% elif vulns %}
<figure>
<table class="sortable">
    <thead>
        <tr><th>Severity</th><th>Name</th><th>Source</th><th>Location</th><th>State</th></tr>
    </thead>
    <tbody>
        {% for v in vulns %}
        <tr{% if v.branch_status == "fixed" or v.report_stale %} class="vuln-fixed"{% endif %}>
            <td><span class="badge-{{ v.severity }}">{{ v.severity }}</span></td>
            <td>
                <a href="{{ v.web_url }}" target="_blank">{{ v.name }}</a>
                {% if v.branch_status == "fixed" %}<br><span class="badge-fixed">fixed in branch</span>{% endif %}
                {% if v.branch_status == "outdated_branch" %}<br><span class="badge-outdated">run branch pipeline</span>{% endif %}
                {% if v.branch_status == "outdated_default" %}<br><span class="badge-outdated">run default pipeline</span>{% endif %}
                {% if v.branch_status == "introduced" %}<br><span class="badge-introduced">introduced in branch</span>{% endif %}
                {% if v.report_stale %}<br><span class="badge-fixed">stale report</span>{% endif %}
            </td>
            <td>{{ v.source }}</td>
            <td>{{ v.location or "" }}</td>
            <td>{{ v.state }}</td>
        </tr>
        {% endfor %}
    </tbody>
</table>
</figure>
{% else %}
<p class="text-center-muted">No vulnerabilities.</p>
{% endif %}
